==> com.idenfy.idenfySdk-1.1.3.4-sources.jar: com/idenfy/idenfySdk/ViewModelsCoreLogic/DocumentsViewModel.java <==
package com.idenfy.idenfySdk.ViewModelsCoreLogic;

import android.app.Application;
import android.arch.lifecycle.AndroidViewModel;
import android.support.annotation.NonNull;

import com.idenfy.idenfySdk.Models.DocumentsTypes.DocumentTypeClass;
import com.idenfy.idenfySdk.Networking.Models.CountryCode;
import com.idenfy.idenfySdk.Networking.Resource;
import com.idenfy.idenfySdk.Networking.RetrofitFactory;

import io.reactivex.Observable;
import io.reactivex.Scheduler;
import io.reactivex.android.schedulers.AndroidSchedulers;
import io.reactivex.disposables.Disposable;
import io.reactivex.schedulers.Schedulers;
import retrofit2.Response;

public class DocumentsViewModel extends AndroidViewModel {
    public DocumentsViewModel(@NonNull Application application, DocumentTypeClass documentTypeClass) {
        super(application);


    }
    public void combineLatest()
    {
        final Observable<String> a = Observable.just("a1", "a2");
        final Observable<String> b = Observable.just("b1");

        final Observable<String> c = Observable.combineLatest(a, b, (first, second) -> first + second);

      Observable.combineLatest(a, b, (first, second) -> first + second);

//      Observable.combineLatest(
//              observeLoadingService(), observeLoadingService(),
//              (first, second) ->
//              {
//              }
//      );

//        Observable.combineLatest(observeLoadingService(), observeLoadingService(), observer ->
//        {
//
//        })
    }


}

==> com.idenfy.idenfySdk-1.1.5.4-sources.jar: com/idenfy/idenfySdk/ViewModelsCoreLogic/DocumentsViewModel.java <==
package com.idenfy.idenfySdk.ViewModelsCoreLogic;

import android.app.Application;
import android.arch.lifecycle.AndroidViewModel;
import android.support.annotation.NonNull;

import com.idenfy.idenfySdk.Models.DocumentsTypes.DocumentTypeClass;
import com.idenfy.idenfySdk.Networking.Models.CountryCode;
import com.idenfy.idenfySdk.Networking.Resource;
import com.idenfy.idenfySdk.Networking.RetrofitFactory;

import io.reactivex.Observable;
import io.reactivex.Scheduler;
import io.reactivex.android.schedulers.AndroidSchedulers;
import io.reactivex.disposables.Disposable;
import io.reactivex.schedulers.Schedulers;
import retrofit2.Response;

public class DocumentsViewModel extends AndroidViewModel {
    public DocumentsViewModel(@NonNull Application application, DocumentTypeClass documentTypeClass) {
        super(application);


    }

    public void combineLatest() {
        final Observable<String> a = Observable.just("a1", "a2");
        final Observable<String> b = Observable.just("b1");

        final Observable<String> c = Observable.combineLatest(a, b, (first, second) -> first + second);

        Observable.combineLatest(a, b, (first, second) -> first + second);

//      Observable.combineLatest(
//              observeLoadingService(), observeLoadingService(),
//              (first, second) ->
//              {
//              }
//      );

//        Observable.combineLatest(observeLoadingService(), observeLoadingService(), observer ->
//        {
//
//        })
    }


}
